cordova.define("com.triedtech.triedapp.plugins.geolocation.Geolocation", function (require, exports, module) {

    var exec = require('cordova/exec');

    var tgeolocation = {

        /**
         * false:没有初始化 true：已经初始化
         */
        initState: false,

        location: null,

        /**
         * 立即触发函数
         * private
         */
        currentFunction: null,

        /**
         * event counter
         */
        currentCounter: 0,

        /**
         * 初始化GPS
         * @param {int} scanSpan 设置GPS取值频率,默认为60000
         */
        init: function (mScanSpan) {
            var me = this,
                mScanSpan = mScanSpan || 60000,
                hasGPS = T.AppConfig ? T.AppConfig.hasGPS : true;

            exec(function (openSetting) {

                /**
                 * openSetting 监听GPS是否打开
                 * 1 ：打开
                 * 0 ：没有打开
                 */
                if (openSetting == "0") {
                    if (typeof Ext !== "undefined") {
                        Ext.Msg.confirm(L.OPENGPS_ACCURATE, L.SETTINGS_GPS, function (buttonId, value) {
                            if (buttonId == "yes") {
                                exec(null, null, "Tgeolocation", "openGPS", []);
                                me.openService(mScanSpan, true);
                            } else {
                                me.openService(mScanSpan, false);
                            }
                        });
                    } else {
                        if (confirm(L.SETTINGS_GPS)) {
                            exec(null, null, "Tgeolocation", "openGPS", []);
                            me.openService(mScanSpan, true);
                        } else {
                            me.openService(mScanSpan, false);
                        }
                    }
                } else {
                    console.log(mScanSpan);
                    me.openService(mScanSpan, true);
                }

            }, null, "Tgeolocation", "init", [hasGPS]);
        },

        /**
         * open service
         * @param scanSpan 设置GPS取值频率
         * @param gpsState GPS状态
         * @method private
         */
        openService: function (scanSpan, gpsState) {
            if (this.initState) {
                exec(null, null, "Tgeolocation", "openService", [scanSpan , gpsState]);
            } else {
                var mScanSpan = scanSpan || 60000;
                this.initState = true;
                this.init(mScanSpan);
            }

        },

        /**
         * close service
         */
        closeService: function () {
            exec(null, null, "Tgeolocation", "closeService", []);
        },

//        /**
//         * setting location
//         * @method private
//         * @param locationData
//         */
//        setLocation: function (locationData) {
//            var me = this;
//            if (locationData.type == 62 || locationData.type == 63 || 162 <= locationData.type && locationData.type <= 167) {
//                return;
//            }
//            if (me.currentCounter) {
//                me.currentFunction(locationData);
//                me.currentCounter = me.currentCounter - 1;
//                me.currentFunction = null;
//            }
//        },

        getLocation: function (success) {
            exec(function (locationData) {
                if (locationData.type == 62 || locationData.type == 63 || 162 <= locationData.type && locationData.type <= 167) {
                    return null;
                }
                success(locationData);
            }, null, "Tgeolocation", "getLocation", []);
        },

        /**
         * get current position
         * @param {Function} fn
         * @method public
         */
        getCurrentPosition: function (fn) {
            this.currentFunction = fn || (function () {
            });
            this.currentCounter = 1;
        }
    };

    module.exports = tgeolocation;
});
